<h1 align="center">http-request-codegen</h1>

<h2 align="center"><a href="https://mondeja.github.io/http-request-codegen">Documentation</a></h2>

<!--start-intro-->
**http-request-codegen** generates HTTP request code snippets for different
implementations. It's perfect if you want to include examples documenting APIs.
Supports the following features:

- Request parameters values randomization using multiples strategies:
    - Random values from lists and functions.
    - Random values from data types.
    - Random values from [Faker providers](https://faker.readthedocs.io/en/master/providers.html).
    - Randomization seeds.
    - Localization.
- Request headers customization.
- Request optional arguments.
- Custom line wrapping.
- Custom indentation.
- Custom quotation character.
- Rendering in one line.
<!--end-intro-->
